@@ -68,6 +68,7 @@ void
 realm_adcli_enroll_join_async (RealmDisco *disco,
                                RealmCredential *cred,
                                GVariant *options,
+                               gboolean use_ldaps,
                                GDBusMethodInvocation *invocation,
                                GAsyncReadyCallback callback,
                                gpointer user_data)
@@ -79,7 +80,8 @@ realm_adcli_enroll_join_async (RealmDisco *disco,
 	GBytes *input = NULL;
 	const gchar *upn;
 	GPtrArray *args;
-	const gchar *os;
+	const gchar *os_n = NULL;
+	const gchar *os_v = NULL;
 	gchar *ccache_arg = NULL;
 	gchar *upn_arg = NULL;
 	gchar *server_arg = NULL;
@@ -102,6 +104,10 @@ realm_adcli_enroll_join_async (RealmDisco *disco,
 	g_ptr_array_add (args, "--domain-realm");
 	g_ptr_array_add (args, (gpointer)disco->kerberos_realm);
 
+	if (use_ldaps) {
+		g_ptr_array_add (args, "--use-ldaps");
+	}
+
 	if (G_IS_INET_SOCKET_ADDRESS (disco->server_address)) {
 		address = g_inet_socket_address_get_address (G_INET_SOCKET_ADDRESS (disco->server_address));
 		server_arg = g_inet_address_to_string (address);
@@ -139,16 +145,16 @@ realm_adcli_enroll_join_async (RealmDisco *disco,
 			g_ptr_array_add (args, (gpointer)computer_ou);
 	}
 
-	os = realm_options_ad_specific (options, "os-name");
-	if (os != NULL && !g_str_equal (os, "")) {
+	os_n = realm_options_ad_specific (options, "os-name");
+	if (os_n != NULL && !g_str_equal (os_n, "")) {
 		g_ptr_array_add (args, "--os-name");
-		g_ptr_array_add (args, (gpointer)os);
+		g_ptr_array_add (args, (gpointer)os_n);
 	}
 
-	os = realm_options_ad_specific (options, "os-version");
-	if (os != NULL && !g_str_equal (os, "")) {
+	os_v = realm_options_ad_specific (options, "os-version");
+	if (os_v != NULL && !g_str_equal (os_v, "")) {
 		g_ptr_array_add (args, "--os-version");
-		g_ptr_array_add (args, (gpointer)os);
+		g_ptr_array_add (args, (gpointer)os_v);
 	}
 
 	switch (cred->type) {
@@ -218,6 +224,7 @@ void
 realm_adcli_enroll_delete_async (RealmDisco *disco,
                                  RealmCredential *cred,
                                  GVariant *options,
+                                 gboolean use_ldaps,
                                  GDBusMethodInvocation *invocation,
                                  GAsyncReadyCallback callback,
                                  gpointer user_data)
@@ -246,6 +253,10 @@ realm_adcli_enroll_delete_async (RealmDisco *disco,
 	g_ptr_array_add (args, "--domain-realm");
 	g_ptr_array_add (args, (gpointer)disco->kerberos_realm);
 
+	if (use_ldaps) {
+		g_ptr_array_add (args, "--use-ldaps");
+	}
+
 	if (G_IS_INET_SOCKET_ADDRESS (disco->server_address)) {
 		address = g_inet_socket_address_get_address (G_INET_SOCKET_ADDRESS (disco->server_address));
 		server_arg = g_inet_address_to_string (address);
