@@ -343,6 +343,7 @@ packages_resolve_async (GDBusConnection *connection,
                         gpointer user_data)
 {
 	guint64 flags = 1 << 18 /* PK_FILTER_ENUM_ARCH */;
+	flags |= 1 << 16 /* PK_FILTER_ENUM_NEWEST */;
 	package_transaction_create ("Resolve", g_variant_new ("(t^as)", flags, package_names),
 	                            connection, cancellable, callback, user_data);
 }
@@ -567,7 +568,7 @@ lookup_required_files_and_packages (const gchar **package_sets,
 		g_ptr_array_add (packages, NULL);
 		*result_packages = (gchar **)g_ptr_array_free (packages, FALSE);
 	} else {
-		g_ptr_array_free (files, TRUE);
+		g_ptr_array_free (packages, TRUE);
 	}
 
 	if (result_files) {
